pub enum Error {
Download(ApiError),
Io(Error),
AudioDecoder(DecoderError),
AudioDuration,
ComputeBuilder(TranscribeBuilderError),
Whisper(WhisperError),
}Expand description
Error conditions
Variants
Download(ApiError)
Error that can occur during model files download from huggingface
Io(Error)
AudioDecoder(DecoderError)
Error that can occur during audio file decoding phase
AudioDuration
The library was unable to determine the audio file duration
ComputeBuilder(TranscribeBuilderError)
Missing parameters to instantiate the whisper cpp backend
Whisper(WhisperError)