Language

Enum Language 

pub enum Language {
Show 99 variants English, Chinese, German, Spanish, Russian, Korean, French, Japanese, Portuguese, Turkish, Polish, Catalan, Dutch, Arabic, Swedish, Italian, Indonesian, Hindi, Finnish, Vietnamese, Hebrew, Ukrainian, Greek, Malay, Czech, Romanian, Danish, Hungarian, Tamil, Norwegian, Thai, Urdu, Croatian, Bulgarian, Lithuanian, Latin, Maori, Malayalam, Welsh, Slovak, Telugu, Persian, Latvian, Bengali, Serbian, Azerbaijani, Slovenian, Kannada, Estonian, Macedonian, Breton, Basque, Icelandic, Armenian, Nepali, Mongolian, Bosnian, Kazakh, Albanian, Swahili, Galician, Marathi, Punjabi, Sinhala, Khmer, Shona, Yoruba, Somali, Afrikaans, Occitan, Georgian, Belarusian, Tajik, Sindhi, Gujarati, Amharic, Yiddish, Lao, Uzbek, Faroese, HaitianCreole, Pashto, Turkmen, Nynorsk, Maltese, Sanskrit, Luxembourgish, Myanmar, Tibetan, Tagalog, Malagasy, Assamese, Tatar, Hawaiian, Lingala, Hausa, Bashkir, Javanese, Sundanese,
}
Languages supported by the tokenizer

Variants



English



Chinese



German



Spanish



Russian



Korean



French



Japanese



Portuguese



Turkish



Polish



Catalan



Dutch



Arabic



Swedish



Italian



Indonesian



Hindi



Finnish



Vietnamese



Hebrew



Ukrainian



Greek



Malay



Czech



Romanian



Danish



Hungarian



Tamil



Norwegian



Thai



Urdu



Croatian



Bulgarian



Lithuanian



Latin



Maori



Malayalam



Welsh



Slovak



Telugu



Persian



Latvian



Bengali



Serbian



Azerbaijani



Slovenian



Kannada



Estonian



Macedonian



Breton



Basque



Icelandic



Armenian



Nepali



Mongolian



Bosnian



Kazakh



Albanian



Swahili



Galician



Marathi



Punjabi



Sinhala



Khmer



Shona



Yoruba



Somali



Afrikaans



Occitan



Georgian



Belarusian



Tajik



Sindhi



Gujarati



Amharic



Yiddish



Lao



Uzbek



Faroese



HaitianCreole



Pashto



Turkmen



Nynorsk



Maltese



Sanskrit



Luxembourgish



Myanmar



Tibetan



Tagalog



Malagasy



Assamese



Tatar



Hawaiian



Lingala



Hausa



Bashkir



Javanese



Sundanese

Implementations

Source

impl Language

pub const fn is_english(&self) -> bool

Returns true if the enum is Language::English otherwise false

pub const fn is_chinese(&self) -> bool

Returns true if the enum is Language::Chinese otherwise false

pub const fn is_german(&self) -> bool

Returns true if the enum is Language::German otherwise false

pub const fn is_spanish(&self) -> bool

Returns true if the enum is Language::Spanish otherwise false

pub const fn is_russian(&self) -> bool

Returns true if the enum is Language::Russian otherwise false

pub const fn is_korean(&self) -> bool

Returns true if the enum is Language::Korean otherwise false

pub const fn is_french(&self) -> bool

Returns true if the enum is Language::French otherwise false

pub const fn is_japanese(&self) -> bool

Returns true if the enum is Language::Japanese otherwise false

pub const fn is_portuguese(&self) -> bool

Returns true if the enum is Language::Portuguese otherwise false

pub const fn is_turkish(&self) -> bool

Returns true if the enum is Language::Turkish otherwise false

pub const fn is_polish(&self) -> bool

Returns true if the enum is Language::Polish otherwise false

pub const fn is_catalan(&self) -> bool

Returns true if the enum is Language::Catalan otherwise false

pub const fn is_dutch(&self) -> bool

Returns true if the enum is Language::Dutch otherwise false

pub const fn is_arabic(&self) -> bool

Returns true if the enum is Language::Arabic otherwise false

pub const fn is_swedish(&self) -> bool

Returns true if the enum is Language::Swedish otherwise false

pub const fn is_italian(&self) -> bool

Returns true if the enum is Language::Italian otherwise false

pub const fn is_indonesian(&self) -> bool

Returns true if the enum is Language::Indonesian otherwise false

pub const fn is_hindi(&self) -> bool

Returns true if the enum is Language::Hindi otherwise false

pub const fn is_finnish(&self) -> bool

Returns true if the enum is Language::Finnish otherwise false

pub const fn is_vietnamese(&self) -> bool

Returns true if the enum is Language::Vietnamese otherwise false

pub const fn is_hebrew(&self) -> bool

Returns true if the enum is Language::Hebrew otherwise false

pub const fn is_ukrainian(&self) -> bool

Returns true if the enum is Language::Ukrainian otherwise false

pub const fn is_greek(&self) -> bool

Returns true if the enum is Language::Greek otherwise false

pub const fn is_malay(&self) -> bool

Returns true if the enum is Language::Malay otherwise false

pub const fn is_czech(&self) -> bool

Returns true if the enum is Language::Czech otherwise false

pub const fn is_romanian(&self) -> bool

Returns true if the enum is Language::Romanian otherwise false

pub const fn is_danish(&self) -> bool

Returns true if the enum is Language::Danish otherwise false

pub const fn is_hungarian(&self) -> bool

Returns true if the enum is Language::Hungarian otherwise false

pub const fn is_tamil(&self) -> bool

Returns true if the enum is Language::Tamil otherwise false

pub const fn is_norwegian(&self) -> bool

Returns true if the enum is Language::Norwegian otherwise false

pub const fn is_thai(&self) -> bool

Returns true if the enum is Language::Thai otherwise false

pub const fn is_urdu(&self) -> bool

Returns true if the enum is Language::Urdu otherwise false

pub const fn is_croatian(&self) -> bool

Returns true if the enum is Language::Croatian otherwise false

pub const fn is_bulgarian(&self) -> bool

Returns true if the enum is Language::Bulgarian otherwise false

pub const fn is_lithuanian(&self) -> bool

Returns true if the enum is Language::Lithuanian otherwise false

pub const fn is_latin(&self) -> bool

Returns true if the enum is Language::Latin otherwise false

pub const fn is_maori(&self) -> bool

Returns true if the enum is Language::Maori otherwise false

pub const fn is_malayalam(&self) -> bool

Returns true if the enum is Language::Malayalam otherwise false

pub const fn is_welsh(&self) -> bool

Returns true if the enum is Language::Welsh otherwise false

pub const fn is_slovak(&self) -> bool

Returns true if the enum is Language::Slovak otherwise false

pub const fn is_telugu(&self) -> bool

Returns true if the enum is Language::Telugu otherwise false

pub const fn is_persian(&self) -> bool

Returns true if the enum is Language::Persian otherwise false

pub const fn is_latvian(&self) -> bool

Returns true if the enum is Language::Latvian otherwise false

pub const fn is_bengali(&self) -> bool

Returns true if the enum is Language::Bengali otherwise false

pub const fn is_serbian(&self) -> bool

Returns true if the enum is Language::Serbian otherwise false

pub const fn is_azerbaijani(&self) -> bool

Returns true if the enum is Language::Azerbaijani otherwise false

pub const fn is_slovenian(&self) -> bool

Returns true if the enum is Language::Slovenian otherwise false

pub const fn is_kannada(&self) -> bool

Returns true if the enum is Language::Kannada otherwise false

pub const fn is_estonian(&self) -> bool

Returns true if the enum is Language::Estonian otherwise false

pub const fn is_macedonian(&self) -> bool

Returns true if the enum is Language::Macedonian otherwise false

pub const fn is_breton(&self) -> bool

Returns true if the enum is Language::Breton otherwise false

pub const fn is_basque(&self) -> bool

Returns true if the enum is Language::Basque otherwise false

pub const fn is_icelandic(&self) -> bool

Returns true if the enum is Language::Icelandic otherwise false

pub const fn is_armenian(&self) -> bool

Returns true if the enum is Language::Armenian otherwise false

pub const fn is_nepali(&self) -> bool

Returns true if the enum is Language::Nepali otherwise false

pub const fn is_mongolian(&self) -> bool

Returns true if the enum is Language::Mongolian otherwise false

pub const fn is_bosnian(&self) -> bool

Returns true if the enum is Language::Bosnian otherwise false

pub const fn is_kazakh(&self) -> bool

Returns true if the enum is Language::Kazakh otherwise false

pub const fn is_albanian(&self) -> bool

Returns true if the enum is Language::Albanian otherwise false

pub const fn is_swahili(&self) -> bool

Returns true if the enum is Language::Swahili otherwise false

pub const fn is_galician(&self) -> bool

Returns true if the enum is Language::Galician otherwise false

pub const fn is_marathi(&self) -> bool

Returns true if the enum is Language::Marathi otherwise false

pub const fn is_punjabi(&self) -> bool

Returns true if the enum is Language::Punjabi otherwise false

pub const fn is_sinhala(&self) -> bool

Returns true if the enum is Language::Sinhala otherwise false

pub const fn is_khmer(&self) -> bool

Returns true if the enum is Language::Khmer otherwise false

pub const fn is_shona(&self) -> bool

Returns true if the enum is Language::Shona otherwise false

pub const fn is_yoruba(&self) -> bool

Returns true if the enum is Language::Yoruba otherwise false

pub const fn is_somali(&self) -> bool

Returns true if the enum is Language::Somali otherwise false

pub const fn is_afrikaans(&self) -> bool

Returns true if the enum is Language::Afrikaans otherwise false

pub const fn is_occitan(&self) -> bool

Returns true if the enum is Language::Occitan otherwise false

pub const fn is_georgian(&self) -> bool

Returns true if the enum is Language::Georgian otherwise false

pub const fn is_belarusian(&self) -> bool

Returns true if the enum is Language::Belarusian otherwise false

pub const fn is_tajik(&self) -> bool

Returns true if the enum is Language::Tajik otherwise false

pub const fn is_sindhi(&self) -> bool

Returns true if the enum is Language::Sindhi otherwise false

pub const fn is_gujarati(&self) -> bool

Returns true if the enum is Language::Gujarati otherwise false

pub const fn is_amharic(&self) -> bool

Returns true if the enum is Language::Amharic otherwise false

pub const fn is_yiddish(&self) -> bool

Returns true if the enum is Language::Yiddish otherwise false

pub const fn is_lao(&self) -> bool

Returns true if the enum is Language::Lao otherwise false

pub const fn is_uzbek(&self) -> bool

Returns true if the enum is Language::Uzbek otherwise false

pub const fn is_faroese(&self) -> bool

Returns true if the enum is Language::Faroese otherwise false

pub const fn is_haitian_creole(&self) -> bool

Returns true if the enum is Language::HaitianCreole otherwise false

pub const fn is_pashto(&self) -> bool

Returns true if the enum is Language::Pashto otherwise false

pub const fn is_turkmen(&self) -> bool

Returns true if the enum is Language::Turkmen otherwise false

pub const fn is_nynorsk(&self) -> bool

Returns true if the enum is Language::Nynorsk otherwise false

pub const fn is_maltese(&self) -> bool

Returns true if the enum is Language::Maltese otherwise false

pub const fn is_sanskrit(&self) -> bool

Returns true if the enum is Language::Sanskrit otherwise false

pub const fn is_luxembourgish(&self) -> bool

Returns true if the enum is Language::Luxembourgish otherwise false

pub const fn is_myanmar(&self) -> bool

Returns true if the enum is Language::Myanmar otherwise false

pub const fn is_tibetan(&self) -> bool

Returns true if the enum is Language::Tibetan otherwise false

pub const fn is_tagalog(&self) -> bool

Returns true if the enum is Language::Tagalog otherwise false

pub const fn is_malagasy(&self) -> bool

Returns true if the enum is Language::Malagasy otherwise false

pub const fn is_assamese(&self) -> bool

Returns true if the enum is Language::Assamese otherwise false

pub const fn is_tatar(&self) -> bool

Returns true if the enum is Language::Tatar otherwise false

pub const fn is_hawaiian(&self) -> bool

Returns true if the enum is Language::Hawaiian otherwise false

pub const fn is_lingala(&self) -> bool

Returns true if the enum is Language::Lingala otherwise false

pub const fn is_hausa(&self) -> bool

Returns true if the enum is Language::Hausa otherwise false

pub const fn is_bashkir(&self) -> bool

Returns true if the enum is Language::Bashkir otherwise false

pub const fn is_javanese(&self) -> bool

Returns true if the enum is Language::Javanese otherwise false

pub const fn is_sundanese(&self) -> bool

Returns true if the enum is Language::Sundanese otherwise false