Model

Enum Model 

pub enum Model {
Show 33 variants Tiny, TinyQ5_1, TinyQ8_0, TinyEn, TinyEnQ5_1, TinyEnQ8_0, Base, BaseQ5_1, BaseQ8_0, BaseEn, BaseEnQ5_1, BaseEnQ8_0, Small, SmallQ5_1, SmallQ8_0, SmallEn, SmallEnQ5_1, SmallEnQ8_0, Medium, MediumQ5_0, MediumQ8_0, MediumEn, MediumEnQ5_0, MediumEnQ8_0, Large, LargeV2, LargeV2Q5_0, LargeV2Q8_0, LargeV3, LargeV3Q5_0, LargeV3Turbo, LargeV3TurboQ5_0, LargeV3TurboQ8_0,
}
OpenAI supported models

Variants



Tiny

The tiny model.



TinyQ5_1

The tiny-q5_1 model.



TinyQ8_0

The tiny-q8_0 model.



TinyEn

The tiny model with only English support.



TinyEnQ5_1

The tiny-q5_1 model with only English support.



TinyEnQ8_0

The tiny-q8_0 model with only English support.



Base

The base model.



BaseQ5_1

The base-q5_1 model.



BaseQ8_0

The base-q8_0 model.



BaseEn

The base model with only English support.



BaseEnQ5_1

The base-q5_1 model with only English support.



BaseEnQ8_0

The base-q8_0 model with only English support.



Small

The small model.



SmallQ5_1

The small-q5_1 model.



SmallQ8_0

The small-q8_0 model.



SmallEn

The small model with only English support.



SmallEnQ5_1

The small-q5_1 model with only English support.



SmallEnQ8_0

The small-q8_0 model with only English support.



Medium

The medium model.



MediumQ5_0

The medium-q5_0 model.



MediumQ8_0

The medium-q8_0 model.



MediumEn

The medium model with only English support.



MediumEnQ5_0

The medium-q5_0 model with only English support.



MediumEnQ8_0

The medium-q8_0 model with only English support.



Large

The large model.



LargeV2

The large model v2.



LargeV2Q5_0



LargeV2Q8_0



LargeV3

The large model v3.



LargeV3Q5_0

The large_v3-q5_0 model v3.



LargeV3Turbo

The large model v3 turbo.



LargeV3TurboQ5_0

The large_v3_turbo-q5_0 model v3 turbo.



LargeV3TurboQ8_0

The large_v3_turbo-q8_0 model v3 turbo.

Implementations

Source

impl Model

pub fn is_multilingual(&self) -> bool

True if the model supports multiple languages, false otherwise.

pub fn cached(&self) -> bool

Check if the file model has been cached before

pub async fn download_model( &self, force_download: bool, ) -> Result<PathBuf, Error>

pub async fn download_model_listener( &self, force_download: bool, tx: UnboundedSender<Event>, ) -> Result<PathBuf, Error>